# openai-cli
Basic utility to interface with OpenAI via command line or terminal.

Users will require an API token form OpenAI.
They'll have to generate their own and store it in an environment called `OPEN_AI_TOKEN`.
